@@ -3,7 +3,6 @@
 """
 
 import datetime
-import json
 import os
 import sys
 import platform
@@ -13,7 +12,7 @@ import zoom.apps
 import zoom.html as h
 from zoom.helpers import link_to, link_to_page
 from zoom.page import page
-from zoom.tools import load_content, today, how_long_ago
+from zoom.tools import load_content, today, how_long_ago, now
 from zoom.users import link_to_user
 
 import views
@@ -104,7 +103,8 @@ def activity_panel(db):
         rows.append(row)
 
     labels = 'id', 'user', 'address', 'path', 'when', 'timestamp', 'elapsed'
-    return zoom.browse(rows, labels=labels, title=link_to_page('Requests'))
+    table_id = 'activity-panel-table'
+    return zoom.browse(rows, table_id=table_id, labels=labels, title=link_to_page('Requests'))
 
 
 def error_panel(db):
@@ -135,7 +135,8 @@ def error_panel(db):
         rows.append(row)
 
     labels = 'id', 'user', 'path', 'when'
-    return zoom.browse(rows, labels=labels, title=link_to_page('Errors'))
+    table_id = 'error-panel-table'
+    return zoom.browse(rows, table_id=table_id, labels=labels, title=link_to_page('Errors'))
 
 
 def warning_panel(db):
@@ -166,44 +167,42 @@ def warning_panel(db):
         rows.append(row)
 
     labels = 'id', 'user', 'path', 'when'
-    return zoom.browse(rows, labels=labels, title=link_to_page('Warnings'))
+    table_id = 'warning-panel-table'
+    return zoom.browse(rows, table_id=table_id, labels=labels, title=link_to_page('Warnings'))
 
 
 def users_panel(db):
 
     host = zoom.system.request.host
+    recent = now() - datetime.timedelta(minutes=60)
 
     data = db("""
     select
         users.username,
-        max(log.timestamp) as timestamp,
-        count(*) as requests
-    from log, users
-        where log.user_id = users.id
-        and timestamp >= %s
-        and server = %s
-        and path not like "%%\\/\\_%%"
+        last_seen
+    from users
+    where
+        last_seen >= %s
     group by users.username
-    order by timestamp desc
+    order by last_seen desc
     limit 10
-    """, today() - datetime.timedelta(days=14), host)
+    """, recent)
 
     rows = []
     for rec in data:
         row = [
             link_to_user(rec[0]),
             how_long_ago(rec[1]),
-            rec[2],
         ]
         rows.append(row)
 
-    labels = 'user', 'last seen', 'requests'
+    labels = 'user', 'last seen'
     return zoom.browse(rows, labels=labels, title=link_to_page('Users'))
 
 
-def callback(method, url=None, timeout=5000):
+def callback(method, url=None, timeout=15000):
     method_name = method.__name__
-    path = url or '/<dz:app_name>/' + method_name
+    path = url or '/{{app_name}}/' + method_name
     js = """
         jQuery(function($){
           setInterval(function(){
@@ -271,8 +270,8 @@ class MyView(zoom.View):
         )
 
     def _index(self):
-        self.model.site.logging = False
-        db = self.model.site.db
+        zoom.get_site().logging = False
+        db = zoom.get_db()
 
         content = zoom.Component(
             views.index_metrics_view(db),
@@ -291,16 +290,16 @@ class MyView(zoom.View):
 
     def log(self):
         """view system log"""
-        save_logging = self.model.site.logging
+        save_logging = zoom.get_site().logging
         try:
             content = callback(self._system_log)
         finally:
-            self.model.site.logging = save_logging
+            zoom.get_site().logging = save_logging
         return page(content, title='System Log')
 
     def _system_log(self):
-        self.model.site.logging = False
-        db = self.model.site.db
+        zoom.get_site().logging = False
+        db = zoom.get_db()
         data = db(
             """
             select
@@ -318,7 +317,7 @@ class MyView(zoom.View):
             when = (zoom.helpers.when(rec[-1]),)
             return rec[0:2] + user + rec[3:-1] + when + rec[-1:]
 
-        db = self.model.site.db
+        db = zoom.get_db()
         data = list(map(fmt, db("""
             select
                 *
@@ -337,7 +336,7 @@ class MyView(zoom.View):
             link = (zoom.link_to(rec[2]),)
             return entry + (rec[1],) + link + rec[3:4] + user + rec[5:]
         path_filter = '' if show_all else 'and path not like "%%\\/\\_%%"'
-        db = self.model.site.db
+        db = zoom.get_db()
         data = db("""
             select
                 id, app, path, status, user_id, address, login, timestamp, elapsed
@@ -353,19 +352,19 @@ class MyView(zoom.View):
         return page(zoom.browse(data, labels=labels), title='Requests', actions=actions)
 
     def performance(self, n=0, limit=50, q=''):
-        db = self.model.site.db
+        db = zoom.get_db()
         return page(log_data(db, ['P'], n, limit, q), title='Performance', search=q, clear='/admin/performance')
 
     def activity(self, n=0, limit=50, q=''):
-        db = self.model.site.db
+        db = zoom.get_db()
         return page(log_data(db, ['A'], n, limit, q), title='Activity', search=q, clear='/admin/activity')
 
     def errors(self, n=0, limit=50, q=''):
-        db = self.model.site.db
+        db = zoom.get_db()
         return page(log_data(db, ['E'], n, limit, q), title='Errors', search=q, clear='/admin/errors')
 
     def warnings(self, n=0, limit=50, q=''):
-        db = self.model.site.db
+        db = zoom.get_db()
         return page(log_data(db, ['W'], n, limit, q), title='Warnings', search=q, clear='/admin/warnings')
 
     def entry(self, key):
@@ -525,7 +524,8 @@ class MyView(zoom.View):
                 ]),
                 h.h2('Variables'),
                 zoom.html.table(
-                    list(os.environ.items())
+                    list(
+                        (k, v.replace(':', ': ') if len(v) > 160 else v) for k, v in os.environ.items())
                 ),
                 css = """
                     .content table { width: 100%; }
