@@ -147,6 +147,7 @@ class AppProxy(object):
     """
 
     def __init__(self, name, filename, site):
+
         self.name = name
         self.filename = filename
 
@@ -178,7 +179,8 @@ class AppProxy(object):
         self.enabled = get('enabled')
         self.author = get('author')
         self.version = get('version')
-        self.theme = get('theme')
+        self.theme = get('theme') or site.theme
+        self.theme_path = existing(site.themes_path, self.theme)
         self.icon = get('icon')
         self.as_icon = self.get_icon_view()
         self.in_development = get('in_development')
@@ -186,19 +188,25 @@ class AppProxy(object):
         self._method = None
         self._templates_paths = None
 
+    @property
+    def icon_class(self):
+        icon = self.config.get('icon')
+        is_bootstrap_icon = icon.startswith('bi-')
+        if is_bootstrap_icon:
+            zoom.requires('bootstrap-icons')
+            return 'bi ' + icon
+        return 'fa fa-' + icon
+
     @property
     def templates_paths(self):
         """Calculate Templates Paths"""
-        join = os.path.join
         if self._templates_paths:
             return self._templates_paths
-        site = self.site
         if self.theme:
-            template_path = existing(join(site.themes_path, self.theme, 'templates'))
-            theme_path = existing(join(site.themes_path, self.theme))
+            template_path = existing(self.theme_path, 'templates')
             paths = list(filter(bool, [
                 template_path,
-                theme_path,
+                self.theme_path,
             ]))
         else:
             paths = []
@@ -210,7 +218,7 @@ class AppProxy(object):
         <div class="zoom-app-as-icon">
             <a href="{self.url}">
                 <div class="zoom-app-icon">
-                    <i class="fa fa-{self.icon}" aria-hidden="true"></i>
+                    <i class="{self.icon_class}" aria-hidden="true"></i>
                 </div>
                 <div class="zoom-app-title">
                     {self.title}
@@ -319,7 +327,7 @@ class AppProxy(object):
                     config.read(system_config_file)
                     return config.get(section, key)
                 except BaseException:
-                    if default != None:
+                    if default is not None:
                         return default
                     else:
                         tpl = 'config setting [{}]{} not found in {} or {} or {}'
@@ -757,4 +765,4 @@ def handler(request, next_handler, *rest):
 
 def get_app():
     """Return the current app"""
-    return zoom.system.request.app
+    return getattr(zoom.system.request, 'app', None)
