@@ -29,7 +29,6 @@ from zoom.response import (
     JavascriptResponse,
     HTMLResponse,
     ICOResponse,
-    TextResponse,
     RedirectResponse,
     TTFResponse,
     WOFFResponse,
@@ -55,6 +54,7 @@ from zoom.page import page
 from zoom.helpers import tag_for
 from zoom.tools import websafe
 from zoom.utils import create_csrf_token
+import zoom.components.flags
 
 
 def debug(request):  # pragma: no cover
@@ -178,7 +178,8 @@ def serve_response(*path):
     )
     exists = os.path.exists
     isfile = os.path.isfile
-    pathname = os.path.realpath(os.path.join(*path))
+    t = os.path.join(*path)
+    pathname = os.path.realpath(t)
 
     logger = logging.getLogger(__name__)
     logger.debug('attempting to serve up file %r', pathname)
@@ -471,8 +472,6 @@ def serve_html(request, handler, *rest):
 
 
 def get_csrf_token(session):
-    """ test """
-
     """generate a csrf token
 
     >>> zoom.system.request.session = session = zoom.utils.Bunch()
@@ -492,6 +491,7 @@ def get_csrf_token(session):
         return session.csrf_token
     return _get_token
 
+
 def check_csrf(request, handler, *rest):
     """Check csrf token
 
@@ -622,7 +622,13 @@ def trap_errors(request, handler, *rest):
     """
     try:
         return handler(request, *rest)
-    except Exception:
+    except Exception as e:
+
+        logger = logging.getLogger(__name__)
+        logger.error(str(e))
+        msg = traceback.format_exc()
+        logger.error(msg)
+
         status = '500 Internal Server Error'
         return HTMLResponse(
             zoom.templates.internal_server_error_500,
@@ -732,7 +738,6 @@ def _handle(request, handler, *rest):  # pragma: no cover
     """invoke the next handler"""
     return handler(request, *rest)
 
-from zoom.components.flags import flag_trap_middleware
 
 def handle(request, handlers=None):  # pragma: no cover
     """handle a request"""
@@ -760,7 +765,7 @@ def handle(request, handlers=None):  # pragma: no cover
         zoom.render.handler,
         display_errors,
         check_csrf,
-        flag_trap_middleware,
+        zoom.components.flags.handle,
         serve_content_images,
         serve_content_files,
         zoom.apps.handler,
